Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Deployments ¶ added in v1.1.0
Deployments returns a list of deployments for the given environment
Types ¶
type Service ¶
type Service interface {
Deployments(env, branch string) ([]string, error)
Deployment(env, branch, name string) (Template, error)
Pods(env, branch string) ([]string, error)
Pod(env, branch, name string) (Template, error)
Environment(branch string) (Template, error)
}
Service is a template service that returns controller and pod templates for given environments
type Template ¶
type Template string
Template is a yaml string template of a controller of a pod
func Deployment ¶ added in v1.1.0
Deployment returns a deployment for the given environment
func Environment ¶ added in v1.1.0
Environment returns an environment template for the given branch
Click to show internal directories.
Click to hide internal directories.